@@ -157,6 +157,9 @@ public:
     case GEARMAN_COMMAND_WORK_FAIL:
     case GEARMAN_COMMAND_ECHO_RES:
     case GEARMAN_COMMAND_WORK_COMPLETE:
+    {
+      ret_ptr = GEARMAND_SUCCESS;
+    }
       break;
 
     case GEARMAN_COMMAND_JOB_CREATED:
@@ -215,14 +218,13 @@ public:
                                     "HTTP/1.0 200 OK\r\n"
                                     "X-Gearman-Job-Handle: %.*s\r\n"
                                     "X-Gearman-Command: %s\r\n"
-                                    "Content-Length: %d\r\n"
+                                    "Content-Length: %" PRIu64 "\r\n"
                                     "Server: Gearman/" PACKAGE_VERSION "\r\n"
-                                    "\r\n%.*s",
+                                    "\r\n",
                                     packet->command == GEARMAN_COMMAND_JOB_CREATED ?  int(packet->arg_size[0]) : int(packet->arg_size[0] - 1),
                                     (const char *)packet->arg[0], // Job handle
                                     gearman_strcommand(packet->command),
-                                    int(content.size()), // Content-length
-                                    int(content.size()), &content[0]);
+                                    (uint64_t)packet->data_size); // Content-length
       }
       else
       {
@@ -236,7 +238,7 @@ public:
                                     packet->command == GEARMAN_COMMAND_JOB_CREATED ?  int(packet->arg_size[0]) : int(packet->arg_size[0] - 1),
                                     (const char *)packet->arg[0],
                                     gearman_strcommand(packet->command),
-                                    uint64_t(content.size()));
+                                    (uint64_t)packet->data_size); // Content-length
       }
 
       _sent_header= true;
@@ -294,7 +296,7 @@ public:
     {
       gearmand_log_error(GEARMAN_DEFAULT_LOG_PARAM, "bad request line: %.*s", (uint32_t)request_size, request);
       set_response(gearmand::protocol::httpd::HTTP_NOT_FOUND);
-      ret_ptr= GEARMAND_SUCCESS;
+      ret_ptr= GEARMAND_INVALID_PACKET;
       return 0;
     }
 
@@ -330,7 +332,7 @@ public:
       {
         gearmand_log_error(GEARMAN_DEFAULT_LOG_PARAM, "bad method: %.*s", (uint32_t)method_size, method_str);
         set_response(gearmand::protocol::httpd::HTTP_METHOD_NOT_ALLOWED);
-        ret_ptr= GEARMAND_SUCCESS;
+        ret_ptr= GEARMAND_INVALID_PACKET;
         return 0;
       }
     }
